// This source code file was last time modified by Igor UA3DJY on 20191104
// All changes are shown in the patch file coming together with the full JTDX source code.
#include "logqso.h"

#include <QTcpSocket>
#include <QString>
#include <QSettings>
#include <QStandardPaths>
#include <QDir>
#include <QDebug>
#include <QMessageBox>

#include "logbook/adif.h"
#include "Configuration.hpp"
#include "Bands.hpp"

#include "ui_logqso.h"
#include "moc_logqso.cpp"

// -----> ja2bqx
#include "logbook/logbook.h"
#include "logbook/countrydat.h"
#include "hamlog50.h"
#include <QFile>

// <----> ja2bqx


LogQSO::LogQSO(QSettings * settings, Configuration const * config, QWidget *parent)
  : QDialog(parent)
  , ui(new Ui::LogQSO)
  , m_settings (settings)
  , m_config {config}
{
  ui->setupUi(this);
//  setWindowTitle("JTDX " + versnumber.simplified () + " - Log QSO");
  setWindowTitle(QCoreApplication::applicationName () + " v" + QCoreApplication::applicationVersion () + " - Log QSO");

  loadSettings ();
}

LogQSO::~LogQSO ()
{
}

void LogQSO::loadSettings ()
{
  m_settings->beginGroup ("LogQSO");
  restoreGeometry (m_settings->value ("geometry", saveGeometry ()).toByteArray ());
  ui->cbTxPower->setChecked (m_settings->value ("SaveTxPower", false).toBool ());
  ui->cbComments->setChecked (m_settings->value ("SaveComments", false).toBool ());
  ui->cbEqslComments->setChecked (m_settings->value ("SaveEQSLComments", false).toBool ());
  m_txPower = m_settings->value ("TxPower", "").toString ();
  m_comments = m_settings->value ("LogComments", "").toString();
  m_eqslcomments = m_settings->value ("LogEQSLComments", "").toString();
  m_settings->endGroup ();
}

void LogQSO::storeSettings () const
{
  m_settings->beginGroup ("LogQSO");
  m_settings->setValue ("geometry", saveGeometry ());
  m_settings->setValue ("SaveTxPower", ui->cbTxPower->isChecked ());
  m_settings->setValue ("SaveComments", ui->cbComments->isChecked ());
  m_settings->setValue ("SaveEQSLComments", ui->cbEqslComments->isChecked ());
  m_settings->setValue ("TxPower", m_txPower);
  m_settings->setValue ("LogComments", m_comments);
  m_settings->setValue ("LogEQSLComments", m_eqslcomments);
  m_settings->endGroup ();
}

void LogQSO::initLogQSO(QString const& hisCall, QString const& hisGrid, QString mode,
                        QString const& rptSent, QString const& rptRcvd, QString const& name,
                        QDateTime const& dateTimeOn, QDateTime const& dateTimeOff,
                        Radio::Frequency dialFreq, bool autologging)
{
  m_send_to_eqsl=m_config->send_to_eqsl();
  ui->call->setText(hisCall);
    ui->call->setText(hisCall);

 //-----> ja2bqx
    ui->search_Call->setText(hisCall);
    m_send_to_hamlog = m_config->send_to_hamlog();
    ui->label_3->setText("");
    ui->label_6->setText("");

     QString dataPath = QStandardPaths::writableLocation(QStandardPaths::DataLocation);
     QString iniFileName =dataPath + "\\JTDX.ini";
     QSettings settings(iniFileName, QSettings::IniFormat);
     settings.beginGroup("Configuration");
     m_HamlogHdb_path = settings.value("HamlogHdbDir").toString();
     settings.endGroup();
     ui->label_6->setText("");
     ui->label_6->setText(m_HamlogHdb_path);
     ui->label_6->setStyleSheet("background-color: rgb(255,255,51);");  //green

     get_thw_qsl_mark();
     // <----- ja2bqx

  ui->grid->setText(hisGrid);
  ui->name->setText(name);
  ui->txPower->setText("");
  ui->comments->setText("");
  ui->eqslcomments->setText("");
  ui->lab11->setVisible(m_send_to_eqsl);
  ui->eqslcomments->setVisible(m_send_to_eqsl);
  ui->cbEqslComments->setVisible(m_send_to_eqsl);
  if (ui->cbTxPower->isChecked ()) ui->txPower->setText(m_txPower);
  if (ui->cbComments->isChecked ()) ui->comments->setText(m_comments);
  if (ui->cbEqslComments->isChecked ()) ui->eqslcomments->setText(m_eqslcomments);
  if(m_config->report_in_comments()) {
    QString t=mode;
    if(rptSent!="") t+="  Sent: " + rptSent;
    if(rptRcvd!="") t+="  Rcvd: " + rptRcvd;
    ui->comments->setText(t);
  }
  if(m_config->log_as_RTTY() and mode.left(3)=="JT9") mode="RTTY";
  ui->mode->setText(mode);
  ui->sent->setText(rptSent);
  ui->rcvd->setText(rptRcvd);
  ui->start_date_time->setDateTime (dateTimeOn);
  ui->end_date_time->setDateTime (dateTimeOff);
  m_dialFreq=dialFreq;
  m_myCall=m_config->my_callsign();
  m_myGrid=m_config->my_grid();
  m_tcp_server_name=m_config->tcp_server_name();
  m_tcp_server_port=m_config->tcp_server_port();
  m_enable_tcp_connection=m_config->enable_tcp_connection();
  m_debug=m_config->write_decoded_debug();
  ui->band->setText(m_config->bands ()->find (dialFreq));

  if(!autologging) {
	 show ();

     // -----> ja2bqx

     countryName="";
     jtdxEntity="";
     thwCode="";
     thwEntityName="";
     check_call="";
     search_call_str="";
     ui->jtdxEntity->setText("");
     ui->thwCode->setText("");
     ui->thwEntityName->setText("");

     len=0;
     ffp0=0;
     ffp1=0;
     ffp2=0;
     ffp3=0;
     ffp4=0;
     ffp5=0;

     search_call_str = ui->search_Call->text().trimmed();
     searchPrefix = search_call_str;

    QString txtStr = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
    QString Left_str;
    Left_str =  searchPrefix.left(1);

    // 1        10
    // 0123456789
    //
    // 11   16  17 20   21   22 24
    // ABCDEF   GHIJ    K    LMN
    //
    // 25     32  33 36
    // OPQRSTUV   WXYZ

    int ia = txtStr.indexOf(Left_str);

    if (ia>0 and ia<11){
        get_entity_from_Unique_callsign_Suuji ();
    } else if (ia>10 and ia<17){
        get_entity_from_Unique_callsign_ABCDEF ();
    } else if (ia>16 and ia<21){
        get_entity_from_Unique_callsign_GHIJ ();
    } else if (ia==21){
        get_entity_from_Unique_callsign_K ();
    } else if (ia>21 and ia<25){
        get_entity_from_Unique_callsign_LMN ();
    } else if (ia>24 and ia<33){
        get_entity_from_Unique_callsign_OPQRSTUV ();
    } else if (ia>32 and ia<37){
        get_entity_from_Unique_callsign_WXYZ ();
    }

    if(ffp0==0){
         LogBook logBook;
         logBook.init_thw();
         check_call = search_call_str;
         logBook.getDXCC(check_call,countryName);

// 擾ꂽ countryName  AS,JD/O,Ogasawara ̗lɂȂB
//void LogQSO::get_thwCode_from_jtdxEntity () ł
//    } else if(jtdxEntity == "JD/o") { Ȃ̂
//       jtdxEntity = jtdxEntity.toUcase();
       
         //ui->comments->setText(countryName);

         QStringList list = countryName.split(",");
         jtdxEntity = list[1].trimmed();
         //jtdxEntity = jtdxEntity.toUcase();B
         //ui->jtdxEntity->setText(jtdxEntity);

//cty.dat ł JD/o Ȃ̂
    int sp = jtdxEntity.indexOf("/");
    if (sp > 0) {
         QStringList list2 = jtdxEntity.split("/");
         jtdxEntity = list2[1].trimmed();
         QString ss0 = list2[0].trimmed();       
         QString ss1 = list2[1].trimmed();       
         jtdxEntity = ss0 + "/" + ss1.toLower();
       }
         ui->jtdxEntity->setText(jtdxEntity);
    }

    get_thwCode_from_jtdxEntity ();

     //jtdxEntity = "3V";
     ui->jtdxEntity->setText(jtdxEntity);
     ui->thwCode->setText(thwCode);
     ui->thwEntityName->setText(thwEntityName);

     if(m_send_to_hamlog){
         search_call_str=ui->search_Call->text();
         ui->label_3->setText("Auto send to Hamlog.hdb");
         ui->label_3->setStyleSheet("background-color: rgb(0,255,0);");
     } else {
         ui->label_3->setText("");
         ui->label_3->setStyleSheet("background-color: rgb(240,240,240);");
     }
         // <---- ja2bqx
  } else {
	 accept();
  }
}

void LogQSO::accept()
{
  QString hisCall,hisGrid,mode,rptSent,rptRcvd,date,time,band;
  QString comments,eqslcomments,name;
  hisCall=ui->call->text();
  hisGrid=ui->grid->text();
  mode=ui->mode->text();
  rptSent=ui->sent->text();
  rptRcvd=ui->rcvd->text();
  m_dateTimeOn = ui->start_date_time->dateTime ();
  m_dateTimeOff = ui->end_date_time->dateTime ();
  band=ui->band->text();
  name=ui->name->text();
  m_txPower=ui->txPower->text();
  comments=ui->comments->text();
  m_comments=comments;
  eqslcomments=ui->eqslcomments->text();
  m_eqslcomments=eqslcomments;
  QString strDialFreq(QString::number(m_dialFreq / 1.e6,'f',6));

  //Log this QSO to ADIF file "wsjtx_log.adi"
  QString filename = "wsjtx_log.adi";  // TODO allow user to set
  ADIF adifile;
  auto adifilePath = QDir {QStandardPaths::writableLocation (QStandardPaths::DataLocation)}.absoluteFilePath ("wsjtx_log.adi");
  adifile.init(adifilePath);
  if (!adifile.addQSOToFile(hisCall,hisGrid,mode,rptSent,rptRcvd,m_dateTimeOn,m_dateTimeOff,band,comments,name,strDialFreq,m_myCall,m_myGrid,m_txPower,m_send_to_eqsl))
  {
      QMessageBox m;
      m.setText("Cannot open file \"" + adifilePath + "\".");
      m.exec();
   }

//Log this QSO to file "wsjtx.log"
  static QFile f {QDir {QStandardPaths::writableLocation (QStandardPaths::DataLocation)}.absoluteFilePath ("wsjtx.log")};
  if(!f.open(QIODevice::Text | QIODevice::Append)) {
    QMessageBox m;
    m.setText("Cannot open file \"" + f.fileName () + "\" for append:" + f.errorString ());
    m.exec();
  } else {
    QString logEntry=m_dateTimeOn.date().toString("yyyy-MM-dd,") +
      m_dateTimeOn.time().toString("hh:mm:ss,") + 
      m_dateTimeOff.date().toString("yyyy-MM-dd,") +
      m_dateTimeOff.time().toString("hh:mm:ss,") + hisCall + "," +
      hisGrid + "," + strDialFreq + "," + mode +
      "," + rptSent + "," + rptRcvd + "," + m_txPower +
      "," + comments + "," + name;
    QTextStream out(&f);
    out << logEntry << endl;
    f.close();
  }

  // -----> ja2bqx
     put_thw_qsl_mark();
  if(m_send_to_hamlog){
   #if		1	// JR2QVA	[2018-02-22] (Thu) 11:00:00      // -----> ja2bqx
      if (1) {
        TThLog log;
        //const char thwName[] = "C:\\Hamlog\\Hamlog.hdb";

        QByteArray thwName = m_HamlogHdb_path.toLocal8Bit();
        HINSTANCE hInstDll = LoadLibraryA("HamLog50.dll");
        if (hInstDll == NULL) {
            QMessageBox::critical(0, "Critical", "Can not open HamLog50.dll");	// error!
        } else {
            int (WINAPI *HL_OPEN)(int (* Func)(char *), TThLog *, const char *, const int);
            void (WINAPI *HL_CLOSE)(TThLog *, const int);
            int (WINAPI *HL_READ)(TThLog *, const long, const int);
            int (WINAPI *HL_APPEND)(TThLog *, const int, int *);
            BOOL (WINAPI *HL_SHARE)(const int);
            HL_OPEN = (int (WINAPI *)(int (* Func)(char *), TThLog *, const char *, const int))
                        GetProcAddress(hInstDll, "HamlogOpen");
            HL_CLOSE = (void (WINAPI *)(TThLog *, const int))
                        GetProcAddress(hInstDll, "HamlogClose");
            HL_READ = (int (WINAPI *)(TThLog *, const long, const int))
                        GetProcAddress(hInstDll, "THW_read");
            HL_APPEND = (int (WINAPI *)(TThLog *, const int, int *))
                        GetProcAddress(hInstDll, "THW_append");
            HL_SHARE = (BOOL (WINAPI *)(const int))
                        GetProcAddress(hInstDll, "SetDbsShare");
            if (HL_OPEN == NULL || HL_CLOSE == NULL || HL_READ == NULL || HL_APPEND == NULL || HL_SHARE == NULL) {
                QMessageBox::critical(0, "Critical", "Can not GetProcAddress");
            } else {
                (*HL_SHARE)(1);		// share open
                if ((*HL_OPEN)(NULL, &log, thwName, 0) == SUCCESS) {
                    memset((char *)&log.Qso, 0, sizeof(TQsoBuff));	// !
                    strcpy(log.Qso.Calls, hisCall.toLatin1());
                    strcpy(log.Qso.Date, m_dateTimeOn.date().toString("yy/MM/dd").toLatin1());
                    strcpy(log.Qso.Time, m_dateTimeOn.time().toString("hh:mmU").toLatin1());
                    strcpy(log.Qso.Code, thwCode.toLatin1());
                    strcpy(log.Qso.Glid, hisGrid.toLatin1());
                    strcpy(log.Qso.Qsl, Qsl_Mark_str.toLatin1());
                    //strcpy(log.Qso.Qsl, "J  ");
                    log.Qso.Flag1 = isDXQSO;	// 8
                    {	// JA?
                        char c1 = log.Qso.Calls[0];
                        char c2 = log.Qso.Calls[1];
                        if (c1 == 'J') {	// JA-JS
                            if (c2 >= 'A' && c2 <= 'S') {
                                log.Qso.Flag1 = 0;
                            }
                        } else if (c1 == '7' || c1 == '8') {	// 7J-7N, 8J-8N
                            if (c2 >= 'J' && c2 <= 'N') {
                                log.Qso.Flag1 = 0;
                            }
                        }
                    }
                    log.Qso.HissLen =  13;
                    log.Qso.MyrsLen =  13;
                    log.Qso.FreqLen =  17;
                    log.Qso.ModeLen =  17;
                    log.Qso.NameLen =  65;
                    //log.Qso.QslLen =    3;
                    log.Qso.QthLen  = 129;
                    log.Qso.Rmk1Len = 255;
                    log.Qso.Rmk2Len = 255;
                    char *p = &log.Qso.Hiss[0];
                    p = (log.Qso.Myrs = p + log.Qso.HissLen);
                    p = (log.Qso.Freq = p + log.Qso.MyrsLen);
                    p = (log.Qso.Mode = p + log.Qso.FreqLen);
                    p = (log.Qso.Name = p + log.Qso.ModeLen);
                    //p = (log.Qso.Qsl  = p + log.Qso.QslLen);
                    p = (log.Qso.Qth  = p + log.Qso.NameLen);
                    p = (log.Qso.Rmk1 = p + log.Qso.QthLen );
                    p = (log.Qso.Rmk2 = p + log.Qso.Rmk1Len);
                    memcpy(log.Qso.Hiss, rptSent.toLatin1(), log.Qso.HissLen);
                    memcpy(log.Qso.Myrs, rptRcvd.toLatin1(), log.Qso.MyrsLen);
                    memcpy(log.Qso.Freq, strDialFreq.toLatin1(), log.Qso.FreqLen);
                    memcpy(log.Qso.Mode, mode.toLatin1(), log.Qso.ModeLen);
                    memcpy(log.Qso.Name, name.toLatin1(), log.Qso.NameLen);
                    //memcpy(log.Qso.Qsl , Qsl_Mark.toLatin1(), log.Qsl.QslLen);
                    memcpy(log.Qso.Qth , thwEntityName.toLatin1(), log.Qso.QthLen);
                        memcpy(log.Qso.Rmk1, comments.toLatin1(), log.Qso.Rmk1Len);	// !
                    // memcpy(log.Qso.Rmk2, "RMK2", log.Qso.Rmk2Len);
                    log.Qso.HissLen--;
                    log.Qso.MyrsLen--;
                    log.Qso.FreqLen--;
                    log.Qso.ModeLen--;
                    log.Qso.NameLen--;
                    log.Qso.QthLen --;
                    log.Qso.Rmk1Len--;
                    log.Qso.Rmk2Len--;
                    int mes = 0;
                    int ret = (*HL_APPEND)(&log, IsQSOdata, &mes);
                    if (ret != SUCCESS) {
                          QMessageBox::critical(0, "Critical", "Can not append");
                    }
                    (*HL_CLOSE)(&log, 0);
                }
            }
            FreeLibrary(hInstDll);
        }
    }
  #endif
  }   //<--- ja2bqx

//Clean up and finish logging
  Q_EMIT acceptQSO (m_dateTimeOff, hisCall, hisGrid, m_dialFreq, mode, rptSent, rptRcvd, m_txPower, comments, name, m_dateTimeOn, eqslcomments);
  if (m_enable_tcp_connection){
    QString myadif;
    QByteArray myadif2;
    myadif="<BAND:" + QString::number(band.length()) + ">" + band;
    myadif+=" <CALL:" + QString::number(hisCall.length()) + ">" + hisCall;
    myadif+=" <FREQ:" + QString::number(strDialFreq.length()) + ">" + strDialFreq;
    if (mode == "FT4") myadif+=" <MODE:4>MFSK <SUBMODE:"  + QString::number(mode.length()) + ">" + mode;
    else myadif+=" <MODE:"  + QString::number(mode.length()) + ">" + mode;
    myadif+=" <QSO_DATE:8>" + m_dateTimeOn.date().toString("yyyyMMdd");
    myadif+=" <TIME_ON:6>" + m_dateTimeOn.time().toString("hhmmss");
    myadif+=" <RST_SENT:" + QString::number(rptSent.length()) + ">" + rptSent;
    myadif+=" <RST_RCVD:" + QString::number(rptRcvd.length()) + ">" + rptRcvd;
    myadif+=" <TX_PWR:" + QString::number(m_txPower.length()) + ">" + m_txPower;
    if (hisGrid.length() > 3) {
      myadif+=" <GRIDSQUARE:" + QString::number(hisGrid.length()) + ">" + hisGrid;
    }
    if (name.length() > 0) {
      myadif+=" <NAME:" + QString::number(name.length()) + ">" + name;
    }
    if (comments.length() > 0) {
      myadif+=" <COMMENT:" + QString::number(comments.length()) + ">" + comments;
    }
    if (m_send_to_eqsl) {
      myadif+=" <EQSL_QSL_SENT:1>Y <EQSL_QSLSDATE:8>" + date;
    }
    myadif+=" <EOR> ";
    myadif="<command:3>Log <parameters:" + QString::number(myadif.length()) + "> " + myadif;
    myadif2 = myadif.toUtf8();
    QTcpSocket socket;
    static QFile f2 {QDir {QStandardPaths::writableLocation (QStandardPaths::DataLocation)}.absoluteFilePath ("tcptrace.txt")};
    bool fopen = false;
    if(m_debug) { 
      if(f2.open(QIODevice::WriteOnly | QIODevice::Text | QIODevice::Append)) fopen = true;
      else {
      QMessageBox::warning (0, "Warning", " File Open Error "
                                  , tr ("Cannot open \"%1\" for append: %2")
                                  .arg (f2.fileName ()).arg (f2.errorString ()));
      }
    }
    if(fopen)  { QTextStream out2(&f2); out2 << QDateTime::currentDateTimeUtc().toString("yyyyMMdd_hhmmss.zzz") << " Connecting to " << m_tcp_server_name << ":" << m_tcp_server_port << endl; }
    socket.connectToHost(m_tcp_server_name, m_tcp_server_port);
    if (socket.waitForConnected(1000)) {
      socket.write(myadif2);
      if(fopen) { QTextStream out2(&f2); out2 << QDateTime::currentDateTimeUtc().toString("yyyyMMdd_hhmmss.zzz") << " Host connected, sent message: " << myadif2 << endl; }
      if (socket.waitForReadyRead(1000)){
        myadif2 = socket.readAll();
        if(fopen) { QTextStream out2(&f2); out2 << QDateTime::currentDateTimeUtc().toString("yyyyMMdd_hhmmss.zzz") << " Received response from host: " << myadif2 << endl; }
        if (myadif2.left(3) == "NAK") {
          QMessageBox::critical(0, "Critical",myadif2 + " QSO data rejected by external software");
        }
      } else {
      if(fopen) { QTextStream out2(&f2); out2 << QDateTime::currentDateTimeUtc().toString("yyyyMMdd_hhmmss.zzz") << " Getting response from host is timed out" << endl; }
      }  
      socket.close();
    } else {
      if(fopen) { QTextStream out2(&f2); out2 << QDateTime::currentDateTimeUtc().toString("yyyyMMdd_hhmmss.zzz") << " Host connection timed out" << endl; }
      QMessageBox::critical(0, "Critical", "TCP QSO data transfer: " + socket.errorString());
    }
    if(fopen) f2.close();
  }
  QDialog::accept();
}

// closeEvent is only called from the system menu close widget for a
// modeless dialog so we use the hideEvent override to store the
// window settings
void LogQSO::hideEvent (QHideEvent * e)
{
  storeSettings ();
  QDialog::hideEvent (e);
}


// ---> ja2bqx


void LogQSO::get_thw_qsl_mark()
{
       QString str; QFile file("thw_qsl_mark.txt"); //jtdx.exe ̂tH_B

      if (!file.open(QIODevice::ReadOnly))
       {
       }
         QTextStream in(&file);
           in >> Qsl_Mark_str;

           if(Qsl_Mark_str=="")
          {
               Qsl_Mark_str = "J";
          }
           ui->Qsl_Mark->setText(Qsl_Mark_str);
}

//write
void LogQSO::put_thw_qsl_mark()
{
      QFile file("thw_qsl_mark.txt"); //jtdx.exe ̂tH_B
      if (!file.open(QIODevice::WriteOnly))
      {
          return;
      }
      QTextStream out(&file);
      Qsl_Mark_str = ui->Qsl_Mark->text().trimmed();
      out << Qsl_Mark_str << endl;
}

// ---> ja2bqx
//cty-2916  20191122

void LogQSO::get_entity_from_Unique_callsign_Suuji ()
{
    if(searchPrefix == "3D2CR") {
        jtdxEntity = "3D2/c";
        ffp0 = 1;
    } else if(searchPrefix == "3D2AG/P") {
        jtdxEntity = "3D2/r";
        ffp0 = 1;
    } else if(searchPrefix == "3D2RI") {
        jtdxEntity = "3D2/r";
        ffp0 = 1;
    } else if(searchPrefix == "3DA0BP/J") {
        jtdxEntity = "3DA";
        ffp0 = 1;
    } else if(searchPrefix == "3Y0E") {
        jtdxEntity = "3Y/b";
        ffp0 = 1;
    } else if(searchPrefix == "3Y0X") {
        jtdxEntity = "3Y/p";
        ffp0 = 1;
    } else if(searchPrefix == "4U1ITU") {
        jtdxEntity = "4U1I";
        ffp0 = 1;
    } else if(searchPrefix == "4U1WRC") {
        jtdxEntity = "4U1I";
        ffp0 = 1;
    } else if(searchPrefix == "4U1UN") {
        jtdxEntity = "4U1U";
        ffp0 = 1;
    } else if(searchPrefix == "4U0R") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U1A") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U1VIC") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U2U") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4Y1A") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "9M4CCB") {
        jtdxEntity = "9M6";
        ffp0 = 1;
    } else if(searchPrefix == "9M4CKT") {
        jtdxEntity = "9M6";
        ffp0 = 1;
    } else if(searchPrefix == "9M4CRB") {
        jtdxEntity = "9M6";
        ffp0 = 1;
    } else if(searchPrefix == "9M4CRP") {
        jtdxEntity = "9M6";
        ffp0 = 1;
    } else if(searchPrefix == "9M4SJSM") {
        jtdxEntity = "9M6";
        ffp0 = 1;
    } else if(searchPrefix == "8J1RL") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "2M0BDR") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "2M0BDT") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "2M0CPN") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "2M0GFC") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "2M0SEG") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "2M0SPX") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "2M0ZET") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "4U0WFP") {
        jtdxEntity = "I";
        ffp0 = 1;
    } else if(searchPrefix == "4U1GSC") {
        jtdxEntity = "I";
        ffp0 = 1;
    } else if(searchPrefix == "4U25B") {
        jtdxEntity = "I";
        ffp0 = 1;
    } else if(searchPrefix == "4U5F") {
        jtdxEntity = "I";
        ffp0 = 1;
    } else if(searchPrefix == "4U73B") {
        jtdxEntity = "I";
        ffp0 = 1;
    } else if(searchPrefix == "4U1WB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "4U0R") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U1A") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U1VIC") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4U2U") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "4Y1A") {
        jtdxEntity = "OE";
        ffp0 = 1;
    }
}



void LogQSO::get_entity_from_Unique_callsign_ABCDEF ()
{
    if(searchPrefix == "C7A") {
        jtdxEntity = "OE";
        ffp0 = 1;
    } else if(searchPrefix == "A41HA/ND") {
        jtdxEntity = "A4";
        ffp0 = 1;
    } else if(searchPrefix == "A41KJ/ND") {
        jtdxEntity = "A4";
        ffp0 = 1;
    } else if(searchPrefix == "A41NN/ND") {
        jtdxEntity = "A4";
        ffp0 = 1;
    } else if(searchPrefix == "A61Q/FD") {
        jtdxEntity = "A6";
        ffp0 = 1;
    } else if(searchPrefix == "BS7H") {
        jtdxEntity = "BS7";
        ffp0 = 1;
    } else if(searchPrefix == "CE6PGO") {
        jtdxEntity = "CE";
        ffp0 = 1;
    } else if(searchPrefix == "CE9/SQ1SGB") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "DP0GVN") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "DP1POL") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "EM1U") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "EM1UA") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "E51PT") {
        jtdxEntity = "E5/n";
        ffp0 = 1;
    } else if(searchPrefix == "E51WL") {
        jtdxEntity = "E5/n";
        ffp0 = 1;
    } else if(searchPrefix == "EA2EZ/P") {
        jtdxEntity = "EA";
        ffp0 = 1;
    } else if(searchPrefix == "EA3HSD/P") {
        jtdxEntity = "EA";
        ffp0 = 1;
    } else if(searchPrefix == "EA5CC/P") {
        jtdxEntity = "EA";
        ffp0 = 1;
    } else if(searchPrefix == "EA5EZ/P") {
        jtdxEntity = "EA";
        ffp0 = 1;
    } else if(searchPrefix == "EA9HU") {
        jtdxEntity = "EA";
        ffp0 = 1;
    } else if(searchPrefix == "EA3RKM/6") {
        jtdxEntity = "EA6";
        ffp0 = 1;
    } else if(searchPrefix == "EA8BFH/P") {
        jtdxEntity = "EA8";
        ffp0 = 1;
    } else if(searchPrefix == "EA1DFP/9") {
        jtdxEntity = "EA9";
        ffp0 = 1;
    } else if(searchPrefix == "FO/F6BCW") {
        jtdxEntity = "FO/m";
        ffp0 = 1;
    } else if(searchPrefix == "AA0O") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AA2IL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AA4DD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AA4R") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AA7TV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AA8R") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AA9HQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AB4B") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AB4EJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AB4GG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AB4IQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AB4KJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AB5OR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AB8RL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AB9DU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC4CA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC4G") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC4GW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC6WI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC6ZM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC7AF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC7P") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AC8Y") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AD1C") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AD4EB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AD4TA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AD8J") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AE4ED") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AE7AP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AG1RL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AG4W") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AG5Z") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AH0U") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AH2O") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AI4DB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AI9K") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AJ4A") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AJ4F") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AJ7G") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AL0A") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AL4B") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AL7GI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AL7R") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AL7RF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "AE7CA") {
        jtdxEntity = "KH2";
        ffp0 = 1;
    } else if(searchPrefix == "AH0FM") {
        jtdxEntity = "KH2";
        ffp0 = 1;
    } else if(searchPrefix == "AC9PT") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "AJ4MY") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "C7A") {
        jtdxEntity = "OE";
        ffp0 = 1;
    }
}



void LogQSO::get_entity_from_Unique_callsign_GHIJ ()
{
    if(searchPrefix == "IA0/IZ1KHY/P") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "GB0SBG") {
        jtdxEntity = "GI";
        ffp0 = 1;
    } else if(searchPrefix == "GB3NGI") {
        jtdxEntity = "GI";
        ffp0 = 1;
    } else if(searchPrefix == "GB4UAS") {
        jtdxEntity = "GI";
        ffp0 = 1;
    } else if(searchPrefix == "GB2ELH") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB3LER") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB3LER/B") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB4LER") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM0AVR") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM0CXQ") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM0EKM") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM0GFL") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM0ILB") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM0JDB") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM1FGN") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM1KKI") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM1ZNR") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM3WHT") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM3ZET") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4IPK") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4JPI") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4LBE") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4LER") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4PXG") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4SLV") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4SSA") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4WXQ") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM4ZHL") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM6RQW") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM6YQA") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM7AFE") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM7GWW") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM8LNH") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM8MMA") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GM8YEC") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GS3ZET") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB0GDS") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB0SSB") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB2CWR") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB2ELH") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB2JCM") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB2OL") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB2SAS") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB3ANG") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB3LER") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB3LER/B") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB4FFS") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB4LER") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "GB0SCB") {
        jtdxEntity = "GW";
        ffp0 = 1;
    } else if(searchPrefix == "GB2IMD") {
        jtdxEntity = "GW";
        ffp0 = 1;
    } else if(searchPrefix == "GB2RSG") {
        jtdxEntity = "GW";
        ffp0 = 1;
    } else if(searchPrefix == "GB2TD") {
        jtdxEntity = "GW";
        ffp0 = 1;
    } else if(searchPrefix == "GB2VK") {
        jtdxEntity = "GW";
        ffp0 = 1;
    } else if(searchPrefix == "HK0TU") {
        jtdxEntity = "HK0/m";
        ffp0 = 1;
    } else if(searchPrefix == "II5BP/J") {
        jtdxEntity = "I";
        ffp0 = 1;
    } else if(searchPrefix == "IK6FAW/J") {
        jtdxEntity = "I";
        ffp0 = 1;
    } else if(searchPrefix == "II0ICH") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "II0IDP") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "II0M") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "II0MQP") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "II0SRE") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0AG") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0AH") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0AH/P") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0AI") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0AK") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0AL") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0AM") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0EH") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0HO") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0ID") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0ID/P") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0NU") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0NU/P") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0NV") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0NV/P") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0OG") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0OH") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0QP") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IQ0SS") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "IY0GA") {
        jtdxEntity = "IS";
        ffp0 = 1;
    } else if(searchPrefix == "JG8NQJ/JD1") {
        jtdxEntity = "JD/m";
        ffp0 = 1;
    } else if(searchPrefix == "JW/LB2PG") {
        jtdxEntity = "JW";
        ffp0 = 1;
    } else if(searchPrefix == "G8ERJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "HF0ANT") {
        jtdxEntity = "VP8/h";
        ffp0 = 1;
    } else if(searchPrefix == "HF0POL") {
        jtdxEntity = "VP8/h";
        ffp0 = 1;
    }
}



void LogQSO::get_entity_from_Unique_callsign_K ()
{
    if(searchPrefix == "KC4AAA") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "KC4AAC") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "KC4USB") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "KC4USV") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "K0ACP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0AU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0DTJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0EJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0IP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0LUZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0NW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0PJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0SN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0TQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K0ZR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K1DW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K1GU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K1KD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K1LT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K1PQS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2DSW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2GMY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2KR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2PM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2PO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2RD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2UR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K2VV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3DMG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3EST") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3IE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3JWI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3PA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3WT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3WYC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K3YP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4AB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4AFE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4AMC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4AVX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4BX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4CWW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4DG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4DXV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4FN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4FT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4HAL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4IE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4IU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4LPQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4MMW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4OAQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4OWR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4RO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4TCG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4TZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4UU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4WG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4WI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4WW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4XU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4YJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K4ZGB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K5AUP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K5EK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K5KG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K5OA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K5VIP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K5WK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K5ZD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K5ZM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K6BFL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K6XT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7ABV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7BV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7DR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7IA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7JOE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7OM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7QA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7SCX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7SV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7TD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7VU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K7ZYV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8AC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8ARY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8CN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8FU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8IA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8JQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8LBQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8LF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8LS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8NYG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8PO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K8SYH") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9DR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9DU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9GWS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9JF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9JM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9OM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9OR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9OZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9RS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9WA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9WZB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "K9YC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KA3MTT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KA4BVG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KA4GAV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KA4OTB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KA8HDE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KA8Q") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KA9FOX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KA9VVQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KB7Q") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KB8KMH") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KB8V") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KB9S") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC2LM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC4HW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC4NX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC4SAW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC4TEO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC4WQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC6X") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC7QY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KC9K") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KD0EE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KD2KW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KD4ADC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KD4EE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KD5DD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KD5M") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KD9BSO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KD9LA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KE0L") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KE0YI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KE1B") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KE2VB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KE3K") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KE4KY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KE8FT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KF4AV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KF5BA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KF5MU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KG4CUY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KG5HVO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KG6MC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH2D") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH2GM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH6CT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH6M") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH6VM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KH6XS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KI6DY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KI6QDH") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KJ4AOM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KJ4IWZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KJ4M") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KJ9C") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KK9A") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KK9N") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL0MP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL2RA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL4CZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL7IKV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL7JR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL7QW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KL7SK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KM4FO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KM4JA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KM7W") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KM9R") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KN1CBR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KN4DUA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KN4FRG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KN8U") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KO0Z") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KO4OL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KO9V") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KP2XX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KP3M") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KP4KD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KP4M") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KQ9J") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KR4F") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KS0CW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KS4L") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KS4X") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KS7T") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KS9W") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KT3M") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KT4O") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KT4RR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KU1CW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KU8E") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KV8S") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KW4J") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KW7D") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KW7Q") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KX2P") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KX4FR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KX4WB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KX4X") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KY0Q") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KY4F") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KY4KD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KZ1W") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KZ9V") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "KG4AY") {
        jtdxEntity = "KG4";
        ffp0 = 1;
    } else if(searchPrefix == "KG4WH") {
        jtdxEntity = "KG4";
        ffp0 = 1;
    } else if(searchPrefix == "K8RN") {
        jtdxEntity = "KH0";
        ffp0 = 1;
    } else if(searchPrefix == "K4QFS") {
        jtdxEntity = "KH2";
        ffp0 = 1;
    } else if(searchPrefix == "KB5OXR") {
        jtdxEntity = "KH2";
        ffp0 = 1;
    } else if(searchPrefix == "KG6DX") {
        jtdxEntity = "KH2";
        ffp0 = 1;
    } else if(searchPrefix == "KG6JDX") {
        jtdxEntity = "KH2";
        ffp0 = 1;
    } else if(searchPrefix == "KH0UM") {
        jtdxEntity = "KH2";
        ffp0 = 1;
    } else if(searchPrefix == "KJ6AYQ") {
        jtdxEntity = "KH2";
        ffp0 = 1;
    } else if(searchPrefix == "K2GT") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "K4XS") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "K6BU") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "K6HNL") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "K9FD") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KA7BSK") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KB1UHL") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KB6EGA") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KB6INB") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KB7WDC") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KD0OXU") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KD4GVR") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KD6NVX") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KD7GWI") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KD8LYB") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KE0JSB") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KE5VQB") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KE6MKW") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KE6TIX") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KE7LWN") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KE7QML") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KG4CAN") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KG4TZD") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KG9MDR") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KH0WJ") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KH3AE") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KH8Z") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KI4YOG") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KI7AUZ") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KJ6COM") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KK4RNF") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KK6RM") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KL0TK") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KL3JC") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KM6UVP") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KQ6M") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "KH8S/NA6M") {
        jtdxEntity = "KH8/s";
        ffp0 = 1;
    } else if(searchPrefix == "K1KAO") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "K4HOE") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "K4PSG") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "K7SGA") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "K7VRK") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KA1NCN") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KB4DX") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KB7BUF") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KC0GLN") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KC0YSW") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KC5YOX") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KC5ZAA") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KD0ONB") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KD2NPD") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KD2SKJ") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KD5WYP") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KD7OOS") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KE7PXV") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF3L") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF4JET") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF5UBP") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF6IAO") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF7FLL") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF7FLM") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF7GKY") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KF7KTH") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KG5MIO") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KG7OUF") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KJ4YOY") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KJ6DCH") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KM4AGL") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KN4HGD") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KN4RXC") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "KW1W") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "K8RF") {
        jtdxEntity = "KP2";
        ffp0 = 1;
    } else if(searchPrefix == "KV4FZ") {
        jtdxEntity = "KP2";
        ffp0 = 1;
    } else if(searchPrefix == "K4LCR") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KB1CKX") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KC2TE") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KC2VCR") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KC8BFN") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KG4GYO") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KK4DCX") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "KP2Z") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    }
}



void LogQSO::get_entity_from_Unique_callsign_LMN ()
{
    if(searchPrefix == "MM0LSM") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM0NQY") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM0VIK") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM0XAU") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM0ZAL") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM0ZCG") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM0ZRC") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM1FJM") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM3VQO") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM5PSL") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM5YLO") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6BDU") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6BZQ") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6IKB") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6IMB") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6MFA") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6PTE") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6SJK") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6YLO") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6ZBG") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM6ZDW") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MM8A") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MS0ZCG") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "MS0ZET") {
        jtdxEntity = "GM";
        ffp0 = 1;
    } else if(searchPrefix == "N0SMX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N1JM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N1RU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N1XK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N2AU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N2BJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N2IC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N2JNR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N3BB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N3BUO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N3CI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N3RA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N3RC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N3ZZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4ARO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4AU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4BAA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4BCB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4BCD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4DW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4HAI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4HID") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4KC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4KG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4KH") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4NA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4NO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4OGW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4QS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4SL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4TZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4UC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4UW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4VI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4VV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4WE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4ZY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N4ZZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5CR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5CW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5DX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5KO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5RP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5SMQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5TB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5TOO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5YT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N5ZO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N6AR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N6DW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7DF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7DR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7FLT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7IP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7IV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7MZW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7NG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7RCS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7US") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7WY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N7ZZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8AID") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8GU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8II") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8NA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8OO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8PR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8RA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N8WXQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9CIQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9GB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9HDE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9JF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9NA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9NB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9NC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9NM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9OU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9RV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9SB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "N9VPV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NA2CC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NA4K") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NA5NN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NA9RB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "ND2T") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "ND3N") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "ND4Y") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NE8P") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NE9U") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NF4J") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NG7A") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NH6T") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NI7R") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NJ4P") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NJ8J") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NK8Q") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NL7CQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NL7D") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NL7QC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NL7XM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NN1N") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NN4NT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NN4SA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NN5O") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NN7A") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NN7CW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NO9E") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NP2GG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NP3K") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NQ6N") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NR5W") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NR7DX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NS4X") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NT0K") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NW7R") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NW8U") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NX1P") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NY6DX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "NH2B") {
        jtdxEntity = "KH0";
        ffp0 = 1;
    } else if(searchPrefix == "N0RY") {
        jtdxEntity = "KH2";
        ffp0 = 1;
    } else if(searchPrefix == "NH0Q") {
        jtdxEntity = "KH2";
        ffp0 = 1;
    } else if(searchPrefix == "N1CBF") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "N3BQY") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "N3GWR") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "N7BMD") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "N7ODC") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "N1TX") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "N6QEK") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "N6ZZX") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "N7DBN") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "N7DKL") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "NJ7H") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "NM0H") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "NU9Q") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "NW7F") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "N2IBR") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "N4CIE") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "N6NVD") {
        jtdxEntity = "KP4";
        ffp0 = 1;
    } else if(searchPrefix == "LU1AW/X") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU1DI/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU1ELY/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU1IG/I") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU1SF/S") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU1UG/U") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU1VDF/V") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU1VYL/V") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU1XAB/V") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU1YJG/V") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU1YY/V") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU2CDE/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU2DVI/H") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU2EE/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU2EGA/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU2ENH/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU2EPL/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU2EPP/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU2FGD/J") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU2WA/W") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU3AYE/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU3DAR/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU3DEY/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU3DJA/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU3DJT/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU3ELR/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU3FCA/F") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU3FV/F") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU3YLF/V") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU4DGC/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU4DLN/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU4KC/K") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU5DA/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU5DGR/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU5DQ/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU5HA/H") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU5HPM/H") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU5QR/Q") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU5YEC/V") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU6DK/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU6EQV/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU6EVD/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU6VEK/W") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU7DHE/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU7DLN/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU7DW/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU7EXX/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU7KGB/O") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU7YG/F") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU8DY/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU8GCJ/GA") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU8VCC/U") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU8VCC/V") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU8XW/XP") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU9AOS/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU9DPI/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU9DPI/I") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU9FBA/F") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU9LOP/L") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW1DXH/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW1ECE/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW2DKF/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW2EQS/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW3DAB/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW3DED/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW3DGC/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW3DJC/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW3DTD/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW3EB/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW3EK/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW5DTD/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW5DUS/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW6DYZ/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW8EGA/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW9DTP/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW9DTQ/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LW9EDX/D") {
        jtdxEntity = "LU";
        ffp0 = 1;
    } else if(searchPrefix == "LU4ZD") {
        jtdxEntity = "VP8/o";
        ffp0 = 1;
    }
}



void LogQSO::get_entity_from_Unique_callsign_OPQRSTUV ()
{
    if(searchPrefix == "RI1ANC") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "RI1ANZ") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "VP8AL") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "VP8CTR") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "VP8HAL") {
        jtdxEntity = "CE9";
        ffp0 = 1;
    } else if(searchPrefix == "TX3X") {
        jtdxEntity = "FK/c";
        ffp0 = 1;
    } else if(searchPrefix == "TO1J") {
        jtdxEntity = "FM";
        ffp0 = 1;
    } else if(searchPrefix == "TO5A") {
        jtdxEntity = "FM";
        ffp0 = 1;
    } else if(searchPrefix == "TO5T") {
        jtdxEntity = "FM";
        ffp0 = 1;
    } else if(searchPrefix == "TO7A") {
        jtdxEntity = "FM";
        ffp0 = 1;
    } else if(searchPrefix == "TX2A") {
        jtdxEntity = "FO/a";
        ffp0 = 1;
    } else if(searchPrefix == "VERSION") {
        jtdxEntity = "FO/a";
        ffp0 = 1;
    } else if(searchPrefix == "TX5P") {
        jtdxEntity = "FO/c";
        ffp0 = 1;
    } else if(searchPrefix == "TX7T") {
        jtdxEntity = "FO/m";
        ffp0 = 1;
    } else if(searchPrefix == "TO80SP") {
        jtdxEntity = "FP";
        ffp0 = 1;
    } else if(searchPrefix == "TO9W") {
        jtdxEntity = "FS";
        ffp0 = 1;
    } else if(searchPrefix == "TO1A") {
        jtdxEntity = "FY";
        ffp0 = 1;
    } else if(searchPrefix == "OV4JAM/J") {
        jtdxEntity = "OZ";
        ffp0 = 1;
    } else if(searchPrefix == "PA0TLM/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PA1AW/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PA1EDL/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PA1ET/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PA2RO/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PA3AFG/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PA4AGO/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PA4WK/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PA6JAM/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PA6SHB/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PA6SJB/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PA9JAS/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PC5D/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PC6RH/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PE18KA/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PE1ORG/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PE1PEX/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PE7M/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PH9GFB/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "PI4VHW/J") {
        jtdxEntity = "PA";
        ffp0 = 1;
    } else if(searchPrefix == "SV2AEL/J") {
        jtdxEntity = "SV";
        ffp0 = 1;
    } else if(searchPrefix == "SV2CLJ/J") {
        jtdxEntity = "SV";
        ffp0 = 1;
    } else if(searchPrefix == "SV2JAO/J") {
        jtdxEntity = "SV";
        ffp0 = 1;
    } else if(searchPrefix == "SZ4SRM/J") {
        jtdxEntity = "SV";
        ffp0 = 1;
    } else if(searchPrefix == "SV2ASP/A") {
        jtdxEntity = "SV/a";
        ffp0 = 1;
    } else if(searchPrefix == "SV2RSG/A") {
        jtdxEntity = "SV/a";
        ffp0 = 1;
    } else if(searchPrefix == "SV0XAZ") {
        jtdxEntity = "SV9";
        ffp0 = 1;
    } else if(searchPrefix == "TA1BZ/2") {
        jtdxEntity = "TA";
        ffp0 = 1;
    } else if(searchPrefix == "TA1D/3") {
        jtdxEntity = "TA";
        ffp0 = 1;
    } else if(searchPrefix == "TA1D/4") {
        jtdxEntity = "TA";
        ffp0 = 1;
    } else if(searchPrefix == "TA1HZ/2") {
        jtdxEntity = "TA";
        ffp0 = 1;
    } else if(searchPrefix == "TA6CQ/1") {
        jtdxEntity = "TA";
        ffp0 = 1;
    } else if(searchPrefix == "R9JBF/1") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R0CM/4") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R100MTK") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R1II/P") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HAT") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HC") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HCE") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HCZ") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HD") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HDC") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HDR") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4HL") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4IC") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4ID") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4II") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4IK") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4IM") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4IN") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4IO") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R4IT") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R7AB/P") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RA4HL") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RA4NCC") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RC4HT") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RC4I") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RD0L/3") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RJ4I") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RJ4P") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RK4HM") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RM4I") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RM4R") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RN4HFJ") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RN4HIF") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RT9T/3") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RU4HD") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RU4HP") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RU4I") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RV1CC/1") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RW4HM") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RW4HTK") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RW4HW") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RW4HZ") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "RW9WJ/4") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA0KCX/3") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA3LMR/P") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4H") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4HBM") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4HGL") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4HIP") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4HRZ") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4HY") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4NF") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA4PN") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA9MA/1") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UA9MA/3") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UC4I") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "UI4I") {
        jtdxEntity = "UA";
        ffp0 = 1;
    } else if(searchPrefix == "R2MWO") {
        jtdxEntity = "UA2";
        ffp0 = 1;
    } else if(searchPrefix == "UA9UAX/2") {
        jtdxEntity = "UA2";
        ffp0 = 1;
    } else if(searchPrefix == "RF1A/9") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "R100KM") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RA/UT5IA") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RA0QK/8") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RN9S") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RO9S") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RT9S") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RT9W") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RU9MV/0") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RV7B/9") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RW3YC/9") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "RW4YA/9") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "UA0ZDY/9") {
        jtdxEntity = "UA9";
        ffp0 = 1;
    } else if(searchPrefix == "VER20191120") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VA2VVV") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VE2CSI") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VE2EKA") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VE2FK") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VE2IDX") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VE2IM") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VE2KK") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VE2NN") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VE8AT") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VY0AA") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VY0PW") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VY2NA/VE2") {
        jtdxEntity = "VE";
        ffp0 = 1;
    } else if(searchPrefix == "VK4FDJL/6") {
        jtdxEntity = "VK";
        ffp0 = 1;
    } else if(searchPrefix == "VK60LZ") {
        jtdxEntity = "VK";
        ffp0 = 1;
    } else if(searchPrefix == "VK6MB/5") {
        jtdxEntity = "VK";
        ffp0 = 1;
    } else if(searchPrefix == "VK0EK") {
        jtdxEntity = "VK0H";
        ffp0 = 1;
    } else if(searchPrefix == "VK0AI") {
        jtdxEntity = "VK0M";
        ffp0 = 1;
    } else if(searchPrefix == "VK3YQS/9") {
        jtdxEntity = "VK9L";
        ffp0 = 1;
    } else if(searchPrefix == "VK3YQS/VK9") {
        jtdxEntity = "VK9L";
        ffp0 = 1;
    } else if(searchPrefix == "VP6D") {
        jtdxEntity = "VP6/d";
        ffp0 = 1;
    } else if(searchPrefix == "VP8CA") {
        jtdxEntity = "VP8/g";
        ffp0 = 1;
    } else if(searchPrefix == "VP8DXU") {
        jtdxEntity = "VP8/s";
        ffp0 = 1;
    }
}



void LogQSO::get_entity_from_Unique_callsign_WXYZ ()
{
    if(searchPrefix == "XQ6CFX") {
        jtdxEntity = "CE";
        ffp0 = 1;
    } else if(searchPrefix == "XQ6OA") {
        jtdxEntity = "CE";
        ffp0 = 1;
    } else if(searchPrefix == "XR6F") {
        jtdxEntity = "CE";
        ffp0 = 1;
    } else if(searchPrefix == "W0BR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W0CN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W0JX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W0MHK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W0PV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W0RIC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W0SK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W0ZP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W1GKT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W1NN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W1PDI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W1PR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W1RH") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W1SRD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W2ACY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W2GS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W2IY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W2VJN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W3DQN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W3HDH") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W3HKK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W3TB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4BCG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4DAN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4ER") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4GKM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4GZX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4JSI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4KW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4LC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4NBS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4NI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4NZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4PF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4RYW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4TLK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4TTM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4UAL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W4UT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W5HIO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W5JR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W5MX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W5NZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W5UE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W5VE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W5VS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W5XB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6GMT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6KGP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6LFB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6NWS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6RLL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6UB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6XR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W6YTG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7DO") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7EE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7HJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7IGC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7II") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7IY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7KF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7RY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7SE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7UT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7XU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8AT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8FJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8FN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8HAP") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8HGH") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8KA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8LYJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8OV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8TK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W8WEJ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9CF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9DC") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9DKB") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9ET") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9IL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9JA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9JEF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9KKN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9LHG") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9MAF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9PL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9RM") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W9RNY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA0WWW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA1FCN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA1UJU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA2VYA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA3C") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA4JA") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA5POK") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA8KAN") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA8OJR") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WA8ZBT") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WB3JFS") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WB4YDL") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WB4YDY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WB7S") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WB8BPU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WB8IMY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WB8YYY") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WB9QAF") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WC7S") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WE6C") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WE6EZ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WF3H") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WF7T") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WF9A") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WH0AI") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WH6AQ") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WH6LE") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WH7R") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WI4T") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WJ9B") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WL7OU") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WM5DX") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WN1G") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WN7S") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WP2B") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WP3ME") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WQ3U") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WQ5L") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WQ9T") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WR5J") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WS6K") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WS6X") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WS9M") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WT2P") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WT8WV") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WU0B") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WU9B") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WV4P") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WV8SW") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WW4R") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WW5M") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WX4W") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WX5S") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WY6K") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WY7FD") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WZ1Y") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WZ4F") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WZ7I") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "WZ8T") {
        jtdxEntity = "K";
        ffp0 = 1;
    } else if(searchPrefix == "W7NX") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "WA6IIQ") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "WA8JQP") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "WB4JTT") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "WB6PIO") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "WY6F") {
        jtdxEntity = "KH6";
        ffp0 = 1;
    } else if(searchPrefix == "W0ZEE") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "W1JM") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "W1LYD") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "W3MKG") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "WH6GBB") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "WH6GCO") {
        jtdxEntity = "KL";
        ffp0 = 1;
    } else if(searchPrefix == "W4LIS") {
        jtdxEntity = "KP2";
        ffp0 = 1;
    }
}



void LogQSO::get_thwCode_from_jtdxEntity ()
{

     if(jtdxEntity == "1A") {
          thwCode ="501A";
          thwEntityName ="Sov Mil Order of Malta";
     } else if(jtdxEntity == "1S") {
               thwCode ="502A";
               thwEntityName ="Spratly Islands";
     } else if(jtdxEntity == "3A") {
               thwCode ="503A";
               thwEntityName ="Monaco";
     } else if(jtdxEntity == "3B6") {
               thwCode ="504A";
               thwEntityName ="Agalega & St. Brandon";
     } else if(jtdxEntity == "3B8") {
               thwCode ="505A";
               thwEntityName ="Mauritius";
     } else if(jtdxEntity == "3B9") {
               thwCode ="506A";
               thwEntityName ="Rodriguez Island";
     } else if(jtdxEntity == "3C") {
               thwCode ="507A";
               thwEntityName ="Equatorial Guinea";
     } else if(jtdxEntity == "3C0") {
               thwCode ="508A";
               thwEntityName ="Annobon Island";
     } else if(jtdxEntity == "3D2") {
               thwCode ="509A";
               thwEntityName ="Fiji";
     } else if(jtdxEntity == "3D2/c") {
               thwCode ="510A";
               thwEntityName ="Conway Reef";
     } else if(jtdxEntity == "3D2/r") {
               thwCode ="511A";
               thwEntityName ="Rotuma Island";
     } else if(jtdxEntity == "3DA") {
               thwCode ="512A";
               thwEntityName ="Swaziland";
     } else if(jtdxEntity == "3V") {
               thwCode ="513A";
               thwEntityName ="Tunisia";
     } else if(jtdxEntity == "3W") {
               thwCode ="514A";
               thwEntityName ="Vietnam";
     } else if(jtdxEntity == "3X") {
               thwCode ="515A";
               thwEntityName ="Guinea";
     } else if(jtdxEntity == "3Y/b") {
               thwCode ="516A";
               thwEntityName ="Bouvet";
     } else if(jtdxEntity == "3Y/p") {
               thwCode ="517A";
               thwEntityName ="Peter 1 Island";
     } else if(jtdxEntity == "4J") {
               thwCode ="739A";
               thwEntityName ="Azerbaijan";
     } else if(jtdxEntity == "4L") {
               thwCode ="730A";
               thwEntityName ="Georgia";
     } else if(jtdxEntity == "4O") {
               thwCode ="851A";
               thwEntityName ="Montenegro";
     } else if(jtdxEntity == "4S") {
               thwCode ="519A";
               thwEntityName ="Sri Lanka";
     } else if(jtdxEntity == "4U1I") {
               thwCode ="520A";
               thwEntityName ="ITU HQ";
     } else if(jtdxEntity == "4U1U") {
               thwCode ="521A";
               thwEntityName ="United Nations HQ";
     } else if(jtdxEntity == "4W") {
               thwCode ="849A";
               thwEntityName ="Timor - Leste";
     } else if(jtdxEntity == "4X") {
               thwCode ="523A";
               thwEntityName ="Israel";
     } else if(jtdxEntity == "5A") {
               thwCode ="524A";
               thwEntityName ="Libya";
     } else if(jtdxEntity == "5B") {
               thwCode ="525A";
               thwEntityName ="Cyprus";
     } else if(jtdxEntity == "5H") {
               thwCode ="526A";
               thwEntityName ="Tanzania";
     } else if(jtdxEntity == "5N") {
               thwCode ="527A";
               thwEntityName ="Nigeria";
     } else if(jtdxEntity == "5R") {
               thwCode ="528A";
               thwEntityName ="Madagascar";
     } else if(jtdxEntity == "5T") {
               thwCode ="529A";
               thwEntityName ="Mauritania";
     } else if(jtdxEntity == "5U") {
               thwCode ="530A";
               thwEntityName ="Niger";
     } else if(jtdxEntity == "5V") {
               thwCode ="531A";
               thwEntityName ="Togo";
     } else if(jtdxEntity == "5W") {
               thwCode ="532A";
               thwEntityName ="Samoa";
     } else if(jtdxEntity == "5X") {
               thwCode ="533A";
               thwEntityName ="Uganda";
     } else if(jtdxEntity == "5Z") {
               thwCode ="534A";
               thwEntityName ="Kenya";
     } else if(jtdxEntity == "6W") {
               thwCode ="535A";
               thwEntityName ="Senegal";
     } else if(jtdxEntity == "6Y") {
               thwCode ="536A";
               thwEntityName ="Jamaica";
     } else if(jtdxEntity == "7O") {
               thwCode ="537A";
               thwEntityName ="Yemen";
     } else if(jtdxEntity == "7P") {
               thwCode ="538A";
               thwEntityName ="Lesotho";
     } else if(jtdxEntity == "7Q") {
               thwCode ="539A";
               thwEntityName ="Malawi";
     } else if(jtdxEntity == "7X") {
               thwCode ="540A";
               thwEntityName ="Algeria";
     } else if(jtdxEntity == "8P") {
               thwCode ="541A";
               thwEntityName ="Barbados";
     } else if(jtdxEntity == "8Q") {
               thwCode ="542A";
               thwEntityName ="Maldives";
     } else if(jtdxEntity == "8R") {
               thwCode ="543A";
               thwEntityName ="Guyana";
     } else if(jtdxEntity == "9A") {
               thwCode ="830A";
               thwEntityName ="Croatia";
     } else if(jtdxEntity == "9G") {
               thwCode ="544A";
               thwEntityName ="Ghana";
     } else if(jtdxEntity == "9H") {
               thwCode ="545A";
               thwEntityName ="Malta";
     } else if(jtdxEntity == "9J") {
               thwCode ="546A";
               thwEntityName ="Zambia";
     } else if(jtdxEntity == "9K") {
               thwCode ="547A";
               thwEntityName ="Kuwait";
     } else if(jtdxEntity == "9L") {
               thwCode ="548A";
               thwEntityName ="Sierra Leone";
     } else if(jtdxEntity == "9M2") {
               thwCode ="549A";
               thwEntityName ="West Malaysia";
     } else if(jtdxEntity == "9M6") {
               thwCode ="550A";
               thwEntityName ="East Malaysia";
     } else if(jtdxEntity == "9N") {
               thwCode ="551A";
               thwEntityName ="Nepal";
     } else if(jtdxEntity == "9Q") {
               thwCode ="552A";
               thwEntityName ="Dem. Rep. of the Congo";
     } else if(jtdxEntity == "9U") {
               thwCode ="553A";
               thwEntityName ="Burundi";
     } else if(jtdxEntity == "9V") {
               thwCode ="554A";
               thwEntityName ="Singapore";
     } else if(jtdxEntity == "9X") {
               thwCode ="555A";
               thwEntityName ="Rwanda";
     } else if(jtdxEntity == "9Y") {
               thwCode ="556A";
               thwEntityName ="Trinidad & Tobago";
     } else if(jtdxEntity == "A2") {
               thwCode ="557A";
               thwEntityName ="Botswana";
     } else if(jtdxEntity == "A3") {
               thwCode ="558A";
               thwEntityName ="Tonga";
     } else if(jtdxEntity == "A4") {
               thwCode ="559A";
               thwEntityName ="Oman";
     } else if(jtdxEntity == "A5") {
               thwCode ="560A";
               thwEntityName ="Bhutan";
     } else if(jtdxEntity == "A6") {
               thwCode ="561A";
               thwEntityName ="United Arab Emirates";
     } else if(jtdxEntity == "A7") {
               thwCode ="562A";
               thwEntityName ="Qatar";
     } else if(jtdxEntity == "A9") {
               thwCode ="563A";
               thwEntityName ="Bahrain";
     } else if(jtdxEntity == "AP") {
               thwCode ="564A";
               thwEntityName ="Pakistan";
     } else if(jtdxEntity == "BS7") {
               thwCode ="843A";
               thwEntityName ="Scarborough Reef";
     } else if(jtdxEntity == "BV") {
               thwCode ="566A";
               thwEntityName ="Taiwan";
     } else if(jtdxEntity == "BV9P") {
               thwCode ="842A";
               thwEntityName ="Pratas Island";
     } else if(jtdxEntity == "BY") {
               thwCode ="565A";
               thwEntityName ="China";
     } else if(jtdxEntity == "C2") {
               thwCode ="567A";
               thwEntityName ="Nauru";
     } else if(jtdxEntity == "C3") {
               thwCode ="568A";
               thwEntityName ="Andorra";
     } else if(jtdxEntity == "C5") {
               thwCode ="569A";
               thwEntityName ="The Gambia";
     } else if(jtdxEntity == "C6") {
               thwCode ="570A";
               thwEntityName ="Bahamas";
     } else if(jtdxEntity == "C9") {
               thwCode ="571A";
               thwEntityName ="Mozambique";
     } else if(jtdxEntity == "CE") {
               thwCode ="572A";
               thwEntityName ="Chile";
     } else if(jtdxEntity == "CE0X") {
               thwCode ="574A";
               thwEntityName ="San Felix & San Ambrosio";
     } else if(jtdxEntity == "CE0Y") {
               thwCode ="573A";
               thwEntityName ="Easter Island";
     } else if(jtdxEntity == "CE0Z") {
               thwCode ="575A";
               thwEntityName ="Juan Fernandez Islands";
     } else if(jtdxEntity == "CE9") {
               thwCode ="826A";
               thwEntityName ="Antarctica";
     } else if(jtdxEntity == "CM") {
               thwCode ="577A";
               thwEntityName ="Cuba";
     } else if(jtdxEntity == "CN") {
               thwCode ="576A";
               thwEntityName ="Morocco";
     } else if(jtdxEntity == "CP") {
               thwCode ="578A";
               thwEntityName ="Bolivia";
     } else if(jtdxEntity == "CT") {
               thwCode ="579A";
               thwEntityName ="Portugal";
     } else if(jtdxEntity == "CT3") {
               thwCode ="580A";
               thwEntityName ="Madeira Islands";
     } else if(jtdxEntity == "CU") {
               thwCode ="581A";
               thwEntityName ="Azores";
     } else if(jtdxEntity == "CX") {
               thwCode ="582A";
               thwEntityName ="Uruguay";
     } else if(jtdxEntity == "CY0") {
               thwCode ="583A";
               thwEntityName ="Sable Island";
     } else if(jtdxEntity == "CY9") {
               thwCode ="584A";
               thwEntityName ="St. Paul Island";
     } else if(jtdxEntity == "D2") {
               thwCode ="585A";
               thwEntityName ="Angola";
     } else if(jtdxEntity == "D4") {
               thwCode ="586A";
               thwEntityName ="Cape Verde";
     } else if(jtdxEntity == "D6") {
               thwCode ="587A";
               thwEntityName ="Comoros";
     } else if(jtdxEntity == "DL") {
               thwCode ="588A";
               thwEntityName ="Fed. Rep. of Germany";
     } else if(jtdxEntity == "DU") {
               thwCode ="589A";
               thwEntityName ="Philippines";
     } else if(jtdxEntity == "E3") {
               thwCode ="841A";
               thwEntityName ="Eritrea";
     } else if(jtdxEntity == "E4") {
               thwCode ="847A";
               thwEntityName ="Palestine";
     } else if(jtdxEntity == "E5/n") {
               thwCode ="813A";
               thwEntityName ="North Cook Islands";
     } else if(jtdxEntity == "E5/s") {
               thwCode ="814A";
               thwEntityName ="South Cook Islands";
     } else if(jtdxEntity == "E6") {
               thwCode ="815A";
               thwEntityName ="Niue";
     } else if(jtdxEntity == "E7") {
               thwCode ="837A";
               thwEntityName ="Bosnia-Herzegovina";
     } else if(jtdxEntity == "EA") {
               thwCode ="590A";
               thwEntityName ="Spain";
     } else if(jtdxEntity == "EA6") {
               thwCode ="591A";
               thwEntityName ="Balearic Islands";
     } else if(jtdxEntity == "EA8") {
               thwCode ="592A";
               thwEntityName ="Canary Islands";
     } else if(jtdxEntity == "EA9") {
               thwCode ="593A";
               thwEntityName ="Ceuta & Melilla";
     } else if(jtdxEntity == "EI") {
               thwCode ="594A";
               thwEntityName ="Ireland";
     } else if(jtdxEntity == "EK") {
               thwCode ="731A";
               thwEntityName ="Armenia";
     } else if(jtdxEntity == "EL") {
               thwCode ="595A";
               thwEntityName ="Liberia";
     } else if(jtdxEntity == "EP") {
               thwCode ="596A";
               thwEntityName ="Iran";
     } else if(jtdxEntity == "ER") {
               thwCode ="747A";
               thwEntityName ="Moldova";
     } else if(jtdxEntity == "ES") {
               thwCode ="740A";
               thwEntityName ="Estonia";
     } else if(jtdxEntity == "ET") {
               thwCode ="597A";
               thwEntityName ="Ethiopia";
     } else if(jtdxEntity == "EU") {
               thwCode ="738A";
               thwEntityName ="Belarus";
     } else if(jtdxEntity == "EX") {
               thwCode ="746A";
               thwEntityName ="Kyrgyzstan";
     } else if(jtdxEntity == "EY") {
               thwCode ="744A";
               thwEntityName ="Tajikistan";
     } else if(jtdxEntity == "EZ") {
               thwCode ="742A";
               thwEntityName ="Turkmenistan";
     } else if(jtdxEntity == "F") {
               thwCode ="598A";
               thwEntityName ="France";
     } else if(jtdxEntity == "FG") {
               thwCode ="599A";
               thwEntityName ="Guadeloupe";
     } else if(jtdxEntity == "FH") {
               thwCode ="600A";
               thwEntityName ="Mayotte";
     } else if(jtdxEntity == "FJ") {
               thwCode ="853A";
               thwEntityName ="St. Barthelemy";
     } else if(jtdxEntity == "FK") {
               thwCode ="601A";
               thwEntityName ="New Caledonia";
     } else if(jtdxEntity == "FK/c") {
               thwCode ="848A";
               thwEntityName ="Chesterfield Islands";
     } else if(jtdxEntity == "FM") {
               thwCode ="602A";
               thwEntityName ="Martinique";
     } else if(jtdxEntity == "FO") {
               thwCode ="603A";
               thwEntityName ="French Polynesia";
     } else if(jtdxEntity == "FO/a") {
               thwCode ="845A";
               thwEntityName ="Austral Islands";
     } else if(jtdxEntity == "FO/c") {
               thwCode ="604A";
               thwEntityName ="Clipperton Island";
     } else if(jtdxEntity == "FO/m") {
               thwCode ="846A";
               thwEntityName ="Marquesas Islands";
     } else if(jtdxEntity == "FP") {
               thwCode ="605A";
               thwEntityName ="St. Pierre & Miquelon";
     } else if(jtdxEntity == "FR") {
               thwCode ="606A";
               thwEntityName ="Reunion Island";
     } else if(jtdxEntity == "FS") {
               thwCode ="610A";
               thwEntityName ="St. Martin";
     } else if(jtdxEntity == "FT/g") {
               thwCode ="607A";
               thwEntityName ="Glorioso Islands";
     } else if(jtdxEntity == "FT/j") {
               thwCode ="608A";
               thwEntityName ="Juan de Nova";
     } else if(jtdxEntity == "FT/t") {
               thwCode ="609A";
               thwEntityName ="Tromelin Island";
     } else if(jtdxEntity == "FT/w") {
               thwCode ="611A";
               thwEntityName ="Crozet Island";
     } else if(jtdxEntity == "FT/x") {
               thwCode ="612A";
               thwEntityName ="Kerguelen Islands";
     } else if(jtdxEntity == "FT/z") {
               thwCode ="613A";
               thwEntityName ="Amsterdam & St. Paul Is.";
     } else if(jtdxEntity == "FW") {
               thwCode ="614A";
               thwEntityName ="Wallis & Futuna Islands";
     } else if(jtdxEntity == "FY") {
               thwCode ="615A";
               thwEntityName ="French Guiana";
     } else if(jtdxEntity == "G") {
               thwCode ="616A";
               thwEntityName ="England";
     } else if(jtdxEntity == "GD") {
               thwCode ="617A";
               thwEntityName ="Isle of Man";
     } else if(jtdxEntity == "GI") {
               thwCode ="618A";
               thwEntityName ="Northern Ireland";
     } else if(jtdxEntity == "GJ") {
               thwCode ="619A";
               thwEntityName ="Jersey";
     } else if(jtdxEntity == "GM") {
               thwCode ="620A";
               thwEntityName ="Scotland";
     } else if(jtdxEntity == "GU") {
               thwCode ="621A";
               thwEntityName ="Guernsey";
     } else if(jtdxEntity == "GW") {
               thwCode ="622A";
               thwEntityName ="Wales";
     } else if(jtdxEntity == "H4") {
               thwCode ="623A";
               thwEntityName ="Solomon Islands";
     } else if(jtdxEntity == "H40") {
               thwCode ="844A";
               thwEntityName ="Temotu Province";
     } else if(jtdxEntity == "HA") {
               thwCode ="624A";
               thwEntityName ="Hungary";
     } else if(jtdxEntity == "HB") {
               thwCode ="625A";
               thwEntityName ="Switzerland";
     } else if(jtdxEntity == "HB0") {
               thwCode ="626A";
               thwEntityName ="Liechtenstein";
     } else if(jtdxEntity == "HC") {
               thwCode ="627A";
               thwEntityName ="Ecuador";
     } else if(jtdxEntity == "HC8") {
               thwCode ="628A";
               thwEntityName ="Galapagos Islands";
     } else if(jtdxEntity == "HH") {
               thwCode ="629A";
               thwEntityName ="Haiti";
     } else if(jtdxEntity == "HI") {
               thwCode ="630A";
               thwEntityName ="Dominican Republic";
     } else if(jtdxEntity == "HK") {
               thwCode ="631A";
               thwEntityName ="Colombia";
     } else if(jtdxEntity == "HK0/a") {
               thwCode ="633A";
               thwEntityName ="San Andres & Providencia";
     } else if(jtdxEntity == "HK0/m") {
               thwCode ="632A";
               thwEntityName ="Malpelo Island";
     } else if(jtdxEntity == "HL") {
               thwCode ="634A";
               thwEntityName ="Republic of Korea";
     } else if(jtdxEntity == "HP") {
               thwCode ="635A";
               thwEntityName ="Panama";
     } else if(jtdxEntity == "HR") {
               thwCode ="636A";
               thwEntityName ="Honduras";
     } else if(jtdxEntity == "HS") {
               thwCode ="637A";
               thwEntityName ="Thailand";
     } else if(jtdxEntity == "HV") {
               thwCode ="638A";
               thwEntityName ="Vatican City";
     } else if(jtdxEntity == "HZ") {
               thwCode ="639A";
               thwEntityName ="Saudi Arabia";
     } else if(jtdxEntity == "I") {
               thwCode ="640A";
               thwEntityName ="Italy";
     } else if(jtdxEntity == "IS") {
               thwCode ="641A";
               thwEntityName ="Sardinia";
     } else if(jtdxEntity == "J2") {
               thwCode ="642A";
               thwEntityName ="Djibouti";
     } else if(jtdxEntity == "J3") {
               thwCode ="643A";
               thwEntityName ="Grenada";
     } else if(jtdxEntity == "J5") {
               thwCode ="644A";
               thwEntityName ="Guinea-Bissau";
     } else if(jtdxEntity == "J6") {
               thwCode ="645A";
               thwEntityName ="St. Lucia";
     } else if(jtdxEntity == "J7") {
               thwCode ="646A";
               thwEntityName ="Dominica";
     } else if(jtdxEntity == "J8") {
               thwCode ="647A";
               thwEntityName ="St. Vincent";
     } else if(jtdxEntity == "JA") {
               thwCode ="500A";
               thwEntityName ="Japan";
     } else if(jtdxEntity == "JD/m") {
               thwCode ="648A";
               thwEntityName ="Minami Torishima";
     } else if(jtdxEntity == "JD/o") {
               thwCode ="649A";
               thwEntityName ="Ogasawara";
     } else if(jtdxEntity == "JT") {
               thwCode ="650A";
               thwEntityName ="Mongolia";
     } else if(jtdxEntity == "JW") {
               thwCode ="651A";
               thwEntityName ="Svalbard";
     } else if(jtdxEntity == "JX") {
               thwCode ="652A";
               thwEntityName ="Jan Mayen";
     } else if(jtdxEntity == "JY") {
               thwCode ="653A";
               thwEntityName ="Jordan";
     } else if(jtdxEntity == "K") {
               thwCode ="784A";
               thwEntityName ="United States";
     } else if(jtdxEntity == "KG4") {
               thwCode ="655A";
               thwEntityName ="Guantanamo Bay";
     } else if(jtdxEntity == "KH0") {
               thwCode ="656A";
               thwEntityName ="Mariana Islands";
     } else if(jtdxEntity == "KH1") {
               thwCode ="657A";
               thwEntityName ="Baker & Howland Islands";
     } else if(jtdxEntity == "KH2") {
               thwCode ="658A";
               thwEntityName ="Guam";
     } else if(jtdxEntity == "KH3") {
               thwCode ="659A";
               thwEntityName ="Johnston Island";
     } else if(jtdxEntity == "KH4") {
               thwCode ="660A";
               thwEntityName ="Midway Island";
     } else if(jtdxEntity == "KH5") {
               thwCode ="661A";
               thwEntityName ="Palmyra & Jarvis Islands";
     } else if(jtdxEntity == "KH6") {
               thwCode ="663A";
               thwEntityName ="Hawaii";
     } else if(jtdxEntity == "KH7K") {
               thwCode ="664A";
               thwEntityName ="Kure Island";
     } else if(jtdxEntity == "KH8") {
               thwCode ="665A";
               thwEntityName ="American Samoa";
     } else if(jtdxEntity == "KH8/s") {
               thwCode ="852A";
               thwEntityName ="Swains Island";
     } else if(jtdxEntity == "KH9") {
               thwCode ="666A";
               thwEntityName ="Wake Island";
     } else if(jtdxEntity == "KL") {
               thwCode ="667A";
               thwEntityName ="Alaska";
     } else if(jtdxEntity == "KP1") {
               thwCode ="668A";
               thwEntityName ="Navassa Island";
     } else if(jtdxEntity == "KP2") {
               thwCode ="669A";
               thwEntityName ="US Virgin Islands";
     } else if(jtdxEntity == "KP4") {
               thwCode ="670A";
               thwEntityName ="Puerto Rico";
     } else if(jtdxEntity == "KP5") {
               thwCode ="671A";
               thwEntityName ="Desecheo Island";
     } else if(jtdxEntity == "LA") {
               thwCode ="672A";
               thwEntityName ="Norway";
     } else if(jtdxEntity == "LU") {
               thwCode ="673A";
               thwEntityName ="Argentina";
     } else if(jtdxEntity == "LX") {
               thwCode ="674A";
               thwEntityName ="Luxembourg";
     } else if(jtdxEntity == "LY") {
               thwCode ="748A";
               thwEntityName ="Lithuania";
     } else if(jtdxEntity == "LZ") {
               thwCode ="675A";
               thwEntityName ="Bulgaria";
     } else if(jtdxEntity == "OA") {
               thwCode ="676A";
               thwEntityName ="Peru";
     } else if(jtdxEntity == "OD") {
               thwCode ="677A";
               thwEntityName ="Lebanon";
     } else if(jtdxEntity == "OE") {
               thwCode ="678A";
               thwEntityName ="Austria";
     } else if(jtdxEntity == "OH") {
               thwCode ="679A";
               thwEntityName ="Finland";
     } else if(jtdxEntity == "OH0") {
               thwCode ="680A";
               thwEntityName ="Aland Islands";
     } else if(jtdxEntity == "OJ0") {
               thwCode ="681A";
               thwEntityName ="Market Reef";
     } else if(jtdxEntity == "OK") {
               thwCode ="839A";
               thwEntityName ="Czech Republic";
     } else if(jtdxEntity == "OM") {
               thwCode ="840A";
               thwEntityName ="Slovak Republic";
     } else if(jtdxEntity == "ON") {
               thwCode ="683A";
               thwEntityName ="Belgium";
     } else if(jtdxEntity == "OX") {
               thwCode ="684A";
               thwEntityName ="Greenland";
     } else if(jtdxEntity == "OY") {
               thwCode ="685A";
               thwEntityName ="Faroe Islands";
     } else if(jtdxEntity == "OZ") {
               thwCode ="686A";
               thwEntityName ="Denmark";
     } else if(jtdxEntity == "P2") {
               thwCode ="687A";
               thwEntityName ="Papua New Guinea";
     } else if(jtdxEntity == "P4") {
               thwCode ="688A";
               thwEntityName ="Aruba";
     } else if(jtdxEntity == "P5") {
               thwCode ="689A";
               thwEntityName ="DPR of Korea";
     } else if(jtdxEntity == "PA") {
               thwCode ="690A";
               thwEntityName ="Netherlands";
     } else if(jtdxEntity == "PJ2") {
               thwCode ="854A";
               thwEntityName ="Curacao";
     } else if(jtdxEntity == "PJ4") {
               thwCode ="855A";
               thwEntityName ="Bonaire";
     } else if(jtdxEntity == "PJ5") {
               thwCode ="856A";
               thwEntityName ="Saba & St. Eustatius";
     } else if(jtdxEntity == "PJ7") {
               thwCode ="857A";
               thwEntityName ="Sint Maarten";
     } else if(jtdxEntity == "PY") {
               thwCode ="693A";
               thwEntityName ="Brazil";
     } else if(jtdxEntity == "PY0F") {
               thwCode ="694A";
               thwEntityName ="Fernando de Noronha";
     } else if(jtdxEntity == "PY0S") {
               thwCode ="695A";
               thwEntityName ="St. Peter & St. Paul";
     } else if(jtdxEntity == "PY0T") {
               thwCode ="696A";
               thwEntityName ="Trindade & Martim Vaz";
     } else if(jtdxEntity == "PZ") {
               thwCode ="697A";
               thwEntityName ="Suriname";
     } else if(jtdxEntity == "R1FJ") {
               thwCode ="734A";
               thwEntityName ="Franz Josef Land";
     } else if(jtdxEntity == "S0") {
               thwCode ="698A";
               thwEntityName ="Western Sahara";
     } else if(jtdxEntity == "S2") {
               thwCode ="699A";
               thwEntityName ="Bangladesh";
     } else if(jtdxEntity == "S5") {
               thwCode ="832A";
               thwEntityName ="Slovenia";
     } else if(jtdxEntity == "S7") {
               thwCode ="700A";
               thwEntityName ="Seychelles";
     } else if(jtdxEntity == "S9") {
               thwCode ="701A";
               thwEntityName ="Sao Tome & Principe";
     } else if(jtdxEntity == "SM") {
               thwCode ="702A";
               thwEntityName ="Sweden";
     } else if(jtdxEntity == "SP") {
               thwCode ="703A";
               thwEntityName ="Poland";
     } else if(jtdxEntity == "ST") {
               thwCode ="704A";
               thwEntityName ="Sudan";
     } else if(jtdxEntity == "SU") {
               thwCode ="706A";
               thwEntityName ="Egypt";
     } else if(jtdxEntity == "SV") {
               thwCode ="707A";
               thwEntityName ="Greece";
     } else if(jtdxEntity == "SV/a") {
               thwCode ="708A";
               thwEntityName ="Mount Athos";
     } else if(jtdxEntity == "SV5") {
               thwCode ="709A";
               thwEntityName ="Dodecanese";
     } else if(jtdxEntity == "SV9") {
               thwCode ="736A";
               thwEntityName ="Crete";
     } else if(jtdxEntity == "T2") {
               thwCode ="711A";
               thwEntityName ="Tuvalu";
     } else if(jtdxEntity == "T30") {
               thwCode ="712A";
               thwEntityName ="Western Kiribati";
     } else if(jtdxEntity == "T31") {
               thwCode ="713A";
               thwEntityName ="Central Kiribati";
     } else if(jtdxEntity == "T32") {
               thwCode ="714A";
               thwEntityName ="Eastern Kiribati";
     } else if(jtdxEntity == "T33") {
               thwCode ="715A";
               thwEntityName ="Banaba Island";
     } else if(jtdxEntity == "T5") {
               thwCode ="716A";
               thwEntityName ="Somalia";
     } else if(jtdxEntity == "T7") {
               thwCode ="717A";
               thwEntityName ="San Marino";
     } else if(jtdxEntity == "T8") {
               thwCode ="654A";
               thwEntityName ="Palau";
     } else if(jtdxEntity == "TA") {
               thwCode ="718A";
               thwEntityName ="Asiatic Turkey";
     } else if(jtdxEntity == "TF") {
               thwCode ="719A";
               thwEntityName ="Iceland";
     } else if(jtdxEntity == "TG") {
               thwCode ="710A";
               thwEntityName ="Guatemala";
     } else if(jtdxEntity == "TI") {
               thwCode ="721A";
               thwEntityName ="Costa Rica";
     } else if(jtdxEntity == "TI9") {
               thwCode ="722A";
               thwEntityName ="Cocos Island";
     } else if(jtdxEntity == "TJ") {
               thwCode ="723A";
               thwEntityName ="Cameroon";
     } else if(jtdxEntity == "TK") {
               thwCode ="724A";
               thwEntityName ="Corsica";
     } else if(jtdxEntity == "TL") {
               thwCode ="725A";
               thwEntityName ="Central African Republic";
     } else if(jtdxEntity == "TN") {
               thwCode ="726A";
               thwEntityName ="Republic of the Congo";
     } else if(jtdxEntity == "TR") {
               thwCode ="727A";
               thwEntityName ="Gabon";
     } else if(jtdxEntity == "TT") {
               thwCode ="728A";
               thwEntityName ="Chad";
     } else if(jtdxEntity == "TU") {
               thwCode ="729A";
               thwEntityName ="Cote d'Ivoire";
     } else if(jtdxEntity == "TY") {
               thwCode ="720A";
               thwEntityName ="Benin";
     } else if(jtdxEntity == "TZ") {
               thwCode ="751A";
               thwEntityName ="Mali";
     } else if(jtdxEntity == "UA") {
               thwCode ="733A";
               thwEntityName ="European Russia";
     } else if(jtdxEntity == "UA2") {
               thwCode ="735A";
               thwEntityName ="Kaliningrad";
     } else if(jtdxEntity == "UA9") {
               thwCode ="732A";
               thwEntityName ="Asiatic Russia";
     } else if(jtdxEntity == "UK") {
               thwCode ="743A";
               thwEntityName ="Uzbekistan";
     } else if(jtdxEntity == "UN") {
               thwCode ="745A";
               thwEntityName ="Kazakhstan";
     } else if(jtdxEntity == "UR") {
               thwCode ="737A";
               thwEntityName ="Ukraine";
     } else if(jtdxEntity == "V2") {
               thwCode ="741A";
               thwEntityName ="Antigua & Barbuda";
     } else if(jtdxEntity == "V3") {
               thwCode ="752A";
               thwEntityName ="Belize";
     } else if(jtdxEntity == "V4") {
               thwCode ="753A";
               thwEntityName ="St. Kitts & Nevis";
     } else if(jtdxEntity == "V5") {
               thwCode ="754A";
               thwEntityName ="Namibia";
     } else if(jtdxEntity == "V6") {
               thwCode ="755A";
               thwEntityName ="Micronesia";
     } else if(jtdxEntity == "V7") {
               thwCode ="756A";
               thwEntityName ="Marshall Islands";
     } else if(jtdxEntity == "V8") {
               thwCode ="757A";
               thwEntityName ="Brunei Darussalam";
     } else if(jtdxEntity == "VE") {
               thwCode ="758A";
               thwEntityName ="Canada";
     } else if(jtdxEntity == "VK") {
               thwCode ="759A";
               thwEntityName ="Australia";
     } else if(jtdxEntity == "VK0H") {
               thwCode ="766A";
               thwEntityName ="Heard Island";
     } else if(jtdxEntity == "VK0M") {
               thwCode ="767A";
               thwEntityName ="Macquarie Island";
     } else if(jtdxEntity == "VK9C") {
               thwCode ="763A";
               thwEntityName ="Cocos (Keeling) Islands";
     } else if(jtdxEntity == "VK9L") {
               thwCode ="760A";
               thwEntityName ="Lord Howe Island";
     } else if(jtdxEntity == "VK9M") {
               thwCode ="764A";
               thwEntityName ="Mellish Reef";
     } else if(jtdxEntity == "VK9N") {
               thwCode ="765A";
               thwEntityName ="Norfolk Island";
     } else if(jtdxEntity == "VK9W") {
               thwCode ="761A";
               thwEntityName ="Willis Island";
     } else if(jtdxEntity == "VK9X") {
               thwCode ="762A";
               thwEntityName ="Christmas Island";
     } else if(jtdxEntity == "VP2E") {
               thwCode ="768A";
               thwEntityName ="Anguilla";
     } else if(jtdxEntity == "VP2M") {
               thwCode ="769A";
               thwEntityName ="Montserrat";
     } else if(jtdxEntity == "VP2V") {
               thwCode ="770A";
               thwEntityName ="British Virgin Islands";
     } else if(jtdxEntity == "VP5") {
               thwCode ="771A";
               thwEntityName ="Turks & Caicos Islands";
     } else if(jtdxEntity == "VP6") {
               thwCode ="779A";
               thwEntityName ="Pitcairn Island";
     } else if(jtdxEntity == "VP6/d") {
               thwCode ="850A";
               thwEntityName ="Ducie Island";
     } else if(jtdxEntity == "VP8") {
               thwCode ="772A";
               thwEntityName ="Falkland Islands";
     } else if(jtdxEntity == "VP8/g") {
               thwCode ="773A";
               thwEntityName ="South Georgia Island";
     } else if(jtdxEntity == "VP8/h") {
               thwCode ="776A";
               thwEntityName ="South Shetland Islands";
     } else if(jtdxEntity == "VP8/o") {
               thwCode ="774A";
               thwEntityName ="South Orkney Islands";
     } else if(jtdxEntity == "VP8/s") {
               thwCode ="775A";
               thwEntityName ="South Sandwich Islands";
     } else if(jtdxEntity == "VP9") {
               thwCode ="777A";
               thwEntityName ="Bermuda";
     } else if(jtdxEntity == "VQ9") {
               thwCode ="778A";
               thwEntityName ="Chagos Islands";
     } else if(jtdxEntity == "VR") {
               thwCode ="780A";
               thwEntityName ="Hong Kong";
     } else if(jtdxEntity == "VU") {
               thwCode ="781A";
               thwEntityName ="India";
     } else if(jtdxEntity == "VU4") {
               thwCode ="782A";
               thwEntityName ="Andaman & Nicobar Is.";
     } else if(jtdxEntity == "VU7") {
               thwCode ="783A";
               thwEntityName ="Lakshadweep Islands";
     } else if(jtdxEntity == "XE") {
               thwCode ="785A";
               thwEntityName ="Mexico";
     } else if(jtdxEntity == "XF4") {
               thwCode ="786A";
               thwEntityName ="Revillagigedo";
     } else if(jtdxEntity == "XT") {
               thwCode ="787A";
               thwEntityName ="Burkina Faso";
     } else if(jtdxEntity == "XU") {
               thwCode ="788A";
               thwEntityName ="Cambodia";
     } else if(jtdxEntity == "XW") {
               thwCode ="789A";
               thwEntityName ="Laos";
     } else if(jtdxEntity == "XX9") {
               thwCode ="790A";
               thwEntityName ="Macao";
     } else if(jtdxEntity == "XZ") {
               thwCode ="791A";
               thwEntityName ="Myanmar";
     } else if(jtdxEntity == "YA") {
               thwCode ="793A";
               thwEntityName ="Afghanistan";
     } else if(jtdxEntity == "YB") {
               thwCode ="794A";
               thwEntityName ="Indonesia";
     } else if(jtdxEntity == "YI") {
               thwCode ="795A";
               thwEntityName ="Iraq";
     } else if(jtdxEntity == "YJ") {
               thwCode ="796A";
               thwEntityName ="Vanuatu";
     } else if(jtdxEntity == "YK") {
               thwCode ="797A";
               thwEntityName ="Syria";
     } else if(jtdxEntity == "YL") {
               thwCode ="749A";
               thwEntityName ="Latvia";
     } else if(jtdxEntity == "YN") {
               thwCode ="798A";
               thwEntityName ="Nicaragua";
     } else if(jtdxEntity == "YO") {
               thwCode ="799A";
               thwEntityName ="Romania";
     } else if(jtdxEntity == "YS") {
               thwCode ="801A";
               thwEntityName ="El Salvador";
     } else if(jtdxEntity == "YU") {
               thwCode ="802A";
               thwEntityName ="Serbia";
     } else if(jtdxEntity == "YV") {
               thwCode ="803A";
               thwEntityName ="Venezuela";
     } else if(jtdxEntity == "YV0") {
               thwCode ="804A";
               thwEntityName ="Aves Island";
     } else if(jtdxEntity == "Z2") {
               thwCode ="805A";
               thwEntityName ="Zimbabwe";
     } else if(jtdxEntity == "Z3") {
               thwCode ="838A";
               thwEntityName ="Macedonia";
     } else if(jtdxEntity == "Z6") {
               thwCode ="859A";
               thwEntityName ="Republic of Kosovo";
     } else if(jtdxEntity == "Z8") {
               thwCode ="858A";
               thwEntityName ="Republic of South Sudan";
     } else if(jtdxEntity == "ZA") {
               thwCode ="806A";
               thwEntityName ="Albania";
     } else if(jtdxEntity == "ZB") {
               thwCode ="807A";
               thwEntityName ="Gibraltar";
     } else if(jtdxEntity == "ZC4") {
               thwCode ="808A";
               thwEntityName ="UK Base Areas on Cyprus";
     } else if(jtdxEntity == "ZD7") {
               thwCode ="809A";
               thwEntityName ="St. Helena";
     } else if(jtdxEntity == "ZD8") {
               thwCode ="810A";
               thwEntityName ="Ascension Island";
     } else if(jtdxEntity == "ZD9") {
               thwCode ="811A";
               thwEntityName ="Tristan da Cunha & Gough";
     } else if(jtdxEntity == "ZF") {
               thwCode ="812A";
               thwEntityName ="Cayman Islands";
     } else if(jtdxEntity == "ZK3") {
               thwCode ="816A";
               thwEntityName ="Tokelau Islands";
     } else if(jtdxEntity == "ZL") {
               thwCode ="817A";
               thwEntityName ="New Zealand";
     } else if(jtdxEntity == "ZL7") {
               thwCode ="818A";
               thwEntityName ="Chatham Islands";
     } else if(jtdxEntity == "ZL8") {
               thwCode ="819A";
               thwEntityName ="Kermadec Islands";
     } else if(jtdxEntity == "ZL9") {
               thwCode ="820A";
               thwEntityName ="N.Z. Subantarctic Is.";
     } else if(jtdxEntity == "ZP") {
               thwCode ="821A";
               thwEntityName ="Paraguay";
     } else if(jtdxEntity == "ZS") {
               thwCode ="822A";
               thwEntityName ="South Africa";
     } else if(jtdxEntity == "ZS8") {
               thwCode ="824A";
               thwEntityName ="Pr. Edward & Marion Is.";
     }
}

// <--- ja2bqx

